
# Slot: temporally related to


holds between two entities with a temporal relationship

URI: [biolink:temporally_related_to](https://w3id.org/biolink/vocab/temporally_related_to)


## Domain and Range

[Occurrent](Occurrent.md) &#8594;  <sub>0..\*</sub> [Occurrent](Occurrent.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children

 *  [preceded by](preceded_by.md)
 *  [precedes](precedes.md)

## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **Exact Mappings:** | | SNOMED:temporally_related_to |
| **Narrow Mappings:** | | RO:0002082 |
|  | | RO:0002083 |
|  | | RO:0002092 |
|  | | RO:0002093 |
|  | | RO:0002223 |
|  | | RO:0002224 |
|  | | RO:0002229 |
|  | | RO:0002230 |
|  | | RO:0002488 |
|  | | RO:0002489 |
|  | | RO:0002492 |
|  | | RO:0002493 |
|  | | RO:0002496 |
|  | | RO:0002497 |

